# torch_memory_saver

Allow torch tensor memory to be released and resumed later 

Please refer to https://github.com/sgl-project/sglang/issues/2542#issuecomment-2563641647 for details.

TODO:

- [x] Implementation
- [ ] More tests and infra
- [ ] Publish to pypi
